//Examples/Swing_Programs

package net.programmingcourse.coursestatistics.model;

import java.io.BufferedReader;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.util.Arrays;
import java.util.Vector;
import java.util.logging.Logger;

/**
 * Class "CsvParser"
 * Generates data records from a CSV file
 * @author Bernhard Steppan
 *
 */
public class CsvFileParser {
  
  private static final Logger logger = Logger.getLogger("CourseStatistics");
  // Separator must be defined country-specifically, e.g. US = , DE = ;
  private String separator = ",";
  
  public Vector<Vector<String>> parseCsvFile(String csvFile)
      throws FileNotFoundException, IOException {
    logger.info("URL of the CSV file:" + csvFile);
    BufferedReader fileReader = null;
    Vector<Vector<String>> records = new Vector<Vector<String>>();
    try {
      String line = "";
      // Create the fileReader:
      fileReader =
        new BufferedReader(new FileReader(csvFile, StandardCharsets.UTF_8));
      // Read file line by line:
      while ((line = fileReader.readLine()) != null) {
        // Read all records:
        String[] dataFields = line.split(separator);
        Vector<String> record =
          new Vector<String>(Arrays.asList(dataFields));
        records.add(record);
        logger.info("Record read and added.");
      }
    logger.info("Reading of the records is finished.");
    } finally {
      if (fileReader != null)
        fileReader.close();
    }
    return records;
  }
}