//Examples/Swing_Programs

package net.programmingcourse.coursestatistics.ui;

import java.util.logging.Logger;

import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.RowFilter;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableModel;
import javax.swing.table.TableRowSorter;

/**
 * Table filter for filtering a Swing table
 * @author Bernhard Steppan
 *
 */
public class TableFilter {
  
  private static final String MESSAGE_NOT_INITIALIZED =
      "Course statistics table model not initialized";
  private static final Logger logger = Logger.getLogger("CourseStatistics");

  /**
   * Creates a filter field associated with a table
   * @param table
   * @return the filterField
   */
  public static JTextField createFilterField(JTable table) {
    
    DefaultTableModel courseStatisticsTableModel =
      (DefaultTableModel) table.getModel();
    if (courseStatisticsTableModel == null) {
      logger.severe(MESSAGE_NOT_INITIALIZED);
      throw new RuntimeException(MESSAGE_NOT_INITIALIZED);
    }
    TableRowSorter<TableModel> tableRowSorter =
      new TableRowSorter<TableModel>();
    tableRowSorter.setModel(courseStatisticsTableModel);
    table.setRowSorter(tableRowSorter);
    final JTextField filterField = new JTextField(10);
    filterField.getDocument().addDocumentListener((DocumentListener)
        new DocumentListener() {
      public void insertUpdate(DocumentEvent e) {
        update(e);
      }
      
      public void removeUpdate(DocumentEvent e) {
        update(e);
      }
      
      public void changedUpdate(DocumentEvent e) {
        update(e);
      }
      
      private void update(DocumentEvent e) {
        logger.info("Update the view");
        String text = filterField.getText();
        if (text.trim().length() == 0) {
          tableRowSorter.setRowFilter(null);
        } else {
          tableRowSorter.setRowFilter(RowFilter.regexFilter("(?i)" + text));
        }
      }
    });
    return filterField;
  }
}