package programmingcourse;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.logging.Logger;

/**
 * CopyLogic – The copy logic of the TransferApp
 * Description: Book "Getting Started With Java Using Eclipse"
 * @author Bernhard Steppan
 * @version 1.0
 */
class CopyLogic {
  
  private static final Logger logger = Logger.getLogger("TransferApp");

  /**
   * This method copies directories and files
   * @param source Source directory
   * @param destination Destination directory
   * @throws IOException arises if something went wrong
   */
  public static void copy(String source, String destination) throws IOException {
    logger.info("Copy from:\n\n" +
     source + "\n\nto:\n\n" + destination);
    rcopy(new File(source), new File(destination));
    logger.info("\nCopy process finished");
  }

  /**
   * Recursive copy function
   * @param source Source
   * @param destination Destination
   * @throws IOException arises if something went wrong
   */
  private static void rcopy(File source, File destination) throws IOException {
    logger.info("Copy from:\n\n" + source + "\n\nto:\n\n" + destination);
    if (source.isDirectory()) { //Is the source a directory?
      destination.mkdir(); //Create directory in the destination path
      String[] directoryEntry = source.list(); // List of directory entries
      for (int i = 0; i < directoryEntry.length; i++) {
        String entry = directoryEntry[i];
        logger.info("\nCopy ".concat(String.valueOf(
            String.valueOf(entry)))); //Debug info
        rcopy(new File(source, entry), //Recursively copy all source directories
            new File(destination, entry)); //... to the destination
      }
    }
    else { //No? Then the source is a file!
      int numberOfBytes;
      byte[] buffer = new byte[32768];
      FileInputStream in = new FileInputStream(source);
      FileOutputStream out = new FileOutputStream(destination);
      while ((numberOfBytes = in.read(buffer)) > 0) {
        out.write(buffer, 0, numberOfBytes);
      }
      in.close(); //Close file input stream 
      out.close(); //Close file output stream
    }
  }
}