package programmingcourse;

import java.io.FileInputStream;
import java.io.IOException;
import java.util.Properties;

/**
 * Transfer – A simple copy program
 * Copyright (c) 2023 by Bernhard Steppan
 * Description: Book "Getting Started With Java Using Eclipse"
 * @author Bernhard Steppan
 * @version 1.0
 */
public class TransferApp {
  
  public TransferApp(String source, String destination) {
    try {
      CopyLogic.copy(source, destination);
    } catch (IOException exception) {
      System.out.println("Error while copying (directories correct?)"
        + ": " + exception.getMessage());
      exception.printStackTrace();
    }
  }
  
  private static void showHelp() {
    System.out.println(
        "Please use two different parameters\n");
    System.out.println("TransferApp <Source> <Destination\n");
    System.out.println("or the following properties file:\n");
    System.out.println("<TransferApp directory>/App.properties\n");
    System.out.println("with the following entries:\n");
    System.out.println("Source <Source directory>");
    System.out.println("Destination <Destination directorys>");
    System.exit(1);
  }
  
  public static void main(String args[]) {
    switch (args.length) {
    case 0: //Case 1: No parameter => try to load the properties file
      String source = null;
      String destination = null;
      try {
        System.out.println("Installation directory:\n\n"
          + System.getProperty("user.dir")+ "\n");
        Properties configuration = new Properties();
        configuration.load(new FileInputStream("App.properties"));
        source = configuration.getProperty("Source");
        destination = configuration.getProperty("Destination");
      } catch (IOException exception) { //Case 1.1: Properties file not found
        System.out.println("Properties file not found: " + exception);
        showHelp(); //Show help
      };
      
      if ((source != null) && (destination != null)) {
        if (source.equals(destination)) { //Case 1.2: Source = Destination
          System.err.println("Error: Source = Destination\n");
          showHelp(); //Show help
        } else { //Case 1.3: Source != Destination
          new TransferApp(source, destination);
        }
      } else {
        System.err.println("Error: Properties file not correct\n");
        showHelp(); //Show help
      }
      break; //Case 1
      
    case 1: //Case 2: Too few parameters
      System.err.println("\nError: Too few parameters\n");
      showHelp();
      break;
      
    case 2: //Case 3: 2 Parameters
      if (args[0].equals(args[1])) { //Case 3.1: Source = Destination
        System.err.println("Error: Source = Destination\n");
        showHelp();
      }
      new TransferApp(args[0], args[1]); //Case 3.2: Source != Destination
      break;
    
    // Exercise on my website:
    default: //Case 4: Too many parameters
      System.err.println("\nError: Too many parameters\n");
      showHelp();
      break;
    }
  }
}